@@ -32,10 +32,6 @@
 #include "yelp-debug.h"
 #include "yelp-settings.h"
 
-#undef stdout
-
-static void           yelp_uri_class_init        (YelpUriClass   *klass);
-static void           yelp_uri_init              (YelpUri        *uri);
 static void           yelp_uri_dispose           (GObject        *object);
 static void           yelp_uri_finalize          (GObject        *object);
 
@@ -65,7 +61,7 @@ static void           resolve_gfile              (YelpUri        *uri,
 static gboolean       is_man_path                (const gchar    *uri,
                                                   const gchar    *encoding);
 
-G_DEFINE_TYPE (YelpUri, yelp_uri, G_TYPE_OBJECT);
+G_DEFINE_TYPE (YelpUri, yelp_uri, G_TYPE_OBJECT)
 #define GET_PRIV(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), YELP_TYPE_URI, YelpUriPrivate))
 
 typedef struct _YelpUriPrivate YelpUriPrivate;
@@ -310,7 +306,6 @@ resolve_start (YelpUri *uri)
 static void
 resolve_sync (YelpUri *uri)
 {
-    gchar *tmp;
     YelpUriPrivate *priv = GET_PRIV (uri);
 
     if (g_str_has_prefix (priv->res_arg, "ghelp:")
@@ -366,6 +361,9 @@ resolve_sync (YelpUri *uri)
         case YELP_URI_DOCUMENT_TYPE_EXTERNAL:
         case YELP_URI_DOCUMENT_TYPE_ERROR:
             break;
+        default:
+            g_assert_not_reached ();
+            break;
         }
     }
     else if (strchr (priv->res_arg, ':')) {
@@ -918,7 +916,8 @@ resolve_help_list_uri (YelpUri *uri)
 static gchar*
 find_man_path (gchar* name, gchar* section)
 {
-    gchar* argv[] = { "man", "-w", NULL, NULL, NULL };
+    const gchar* argv[] = { "man", "-w", NULL, NULL, NULL };
+    gchar **my_argv;
     gchar *ystdout = NULL;
     gint status;
     gchar **lines;
@@ -933,7 +932,10 @@ find_man_path (gchar* name, gchar* section)
         argv[2] = name;
     }
 
-    if (!g_spawn_sync (NULL, argv, NULL,
+    /* g_strdupv() should accept a "const gchar **". */
+    my_argv = g_strdupv ((gchar **) argv);
+
+    if (!g_spawn_sync (NULL, my_argv, NULL,
                        G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL,
                        NULL, NULL,
                        &ystdout, NULL, &status, &error)) {
@@ -942,6 +944,8 @@ find_man_path (gchar* name, gchar* section)
         g_error_free (error);
     }
 
+    g_strfreev (my_argv);
+
     if (status == 0) {
         lines = g_strsplit (ystdout, "\n", 2);
         g_free (ystdout);
